@@ -33,16 +33,19 @@ import jenkins_jobs.modules.helpers as helpers
 def http_endpoint(registry, xml_parent, data):
     """yaml: http
     Defines an HTTP notification endpoint.
-    Requires the Jenkins :jenkins-wiki:`Notification Plugin
-    <Notification+Plugin>`.
+
+    Requires the Jenkins :jenkins-plugins:`Notification Plugin
+    <notification>`.
 
     :arg str format: notification payload format, JSON (default) or XML
     :arg str event: job events that trigger notifications: started,
         completed, finalized or all (default)
     :arg str url: URL of the endpoint
-    :arg str timeout: Timeout in milliseconds for sending notification
+    :arg int timeout: Timeout in milliseconds for sending notification
         request (30 seconds by default)
-    :arg str log: Number lines of log messages to send (0 by default).
+    :arg int retries: Nr of times to retry sending notification in case
+        sending notification fails. (0 by default)
+    :arg int log: Number lines of log messages to send (0 by default).
         Use -1 for all (use with caution).
 
     Example:
@@ -64,6 +67,7 @@ def http_endpoint(registry, xml_parent, data):
         ("", "protocol", "HTTP"),
         ("", "event", event, supported_events),
         ("timeout", "timeout", 30000),
+        ("retries", "retries", 0),
         ("url", "url", None),
         ("log", "loglines", 0),
     ]
