@@ -652,8 +652,8 @@ def dynamic_choice_param(registry, xml_parent, data):
     """yaml: dynamic-choice
     Dynamic Choice Parameter
 
-    Requires the Jenkins :jenkins-wiki:`Jenkins Dynamic Parameter Plug-in
-    <Dynamic+Parameter+Plug-in>`.
+    Requires the Jenkins :jenkins-plugins:`Jenkins Dynamic Parameter Plug-in
+    <dynamicparameter>`.
 
     :arg str name: the name of the parameter
     :arg str description: a description of the parameter (optional)
@@ -681,8 +681,8 @@ def dynamic_string_param(registry, xml_parent, data):
     """yaml: dynamic-string
     Dynamic Parameter
 
-    Requires the Jenkins :jenkins-wiki:`Jenkins Dynamic Parameter Plug-in
-    <Dynamic+Parameter+Plug-in>`.
+    Requires the Jenkins :jenkins-plugins:`Jenkins Dynamic Parameter Plug-in
+    <dynamicparameter>`.
 
     :arg str name: the name of the parameter
     :arg str description: a description of the parameter (optional)
@@ -710,8 +710,8 @@ def dynamic_choice_scriptler_param(registry, xml_parent, data):
     """yaml: dynamic-choice-scriptler
     Dynamic Choice Parameter (Scriptler)
 
-    Requires the Jenkins :jenkins-wiki:`Jenkins Dynamic Parameter Plug-in
-    <Dynamic+Parameter+Plug-in>`.
+    Requires the Jenkins :jenkins-plugins:`Jenkins Dynamic Parameter Plug-in
+    <dynamicparameter>`.
 
     :arg str name: the name of the parameter
     :arg str description: a description of the parameter (optional)
@@ -749,8 +749,8 @@ def dynamic_string_scriptler_param(registry, xml_parent, data):
     """yaml: dynamic-string-scriptler
     Dynamic Parameter (Scriptler)
 
-    Requires the Jenkins :jenkins-wiki:`Jenkins Dynamic Parameter Plug-in
-    <Dynamic+Parameter+Plug-in>`.
+    Requires the Jenkins :jenkins-plugins:`Jenkins Dynamic Parameter Plug-in
+    <dynamicparameter>`.
 
     :arg str name: the name of the parameter
     :arg str description: a description of the parameter (optional)
@@ -1200,8 +1200,8 @@ def active_choices_param(registry, xml_parent, data):
     """yaml: active-choices
     Active Choices Parameter
 
-    Requires the Jenkins :jenkins-wiki:`Active Choices Plug-in
-    <active+choices+plugin>`.
+    Requires the Jenkins :jenkins-plugins:`Active Choices Plug-in
+    <uno-choice>`.
 
     :arg str name: Name of the parameter (required).
     :arg str description: Description of the parameter.
@@ -1249,6 +1249,77 @@ def active_choices_param(registry, xml_parent, data):
     element_name = "org.biouno.unochoice.ChoiceParameter"
     pdef = XML.SubElement(xml_parent, element_name)
 
+    __active_choice_param_internal(pdef, data)
+
+
+def active_choices_reactive_param(registry, xml_parent, data):
+    """yaml: active-choices-reactive
+    Active Choices Reactive Parameter
+
+    Requires the Jenkins :jenkins-plugins:`Active Choices Plug-in
+    <uno-choice>`.
+
+    :arg str name: Name of the parameter (required).
+    :arg str description: Description of the parameter.
+    :arg list script: Use a Groovy script to define the parameter.
+
+        :Parameter: * **groovy** (`str`) Groovy DSL Script
+                    * **use-groovy-sandbox** (`bool`) To run this
+                        Groovy script in a sandbox with limited abilities
+                        (default True)
+                    * **script-additional-classpath** (`list`) Additional
+                        classpath entries accessible from the script.
+    :arg list fallback-script: Use a Fallback script. If the script
+        (specified above) fails, the fallback script will be used as a fallback.
+
+        :Parameter: * **groovy** (`str`) Groovy DSL Script
+                    * **use-groovy-sandbox** (`bool`) To run this Groovy
+                        script in a sandbox with limited abilities.
+                        (default True)
+                    * **script-additional-classpath** (`list`) Additional
+                        classpath entries accessible from the script.
+    :arg bool enable-filters: If enabled a text box will appear next to
+        this element and will permit the user to filter its entries. The
+        list values never get re-evaluated (default False).
+    :arg int filter-starts-at: How many characters a user must enter
+        before the filter is applied (default 1).
+    :arg str choice-type: type of the choices. (default 'single-select')
+
+        :Allowed Values: * **single-select**
+                    * **multi-select**
+                    * **radio-buttons**
+                    * **checkboxes**
+    :arg str referenced-parameters: Comma separated list of other job
+        parameters referenced in the uno-choice script
+
+    Minimal Example:
+
+    .. literalinclude::
+        /../../tests/yamlparser/fixtures/active-choices-reactive-param001.yaml
+       :language: yaml
+
+    Full Example:
+
+    .. literalinclude::
+        /../../tests/yamlparser/fixtures/active-choices-reactive-param002.yaml
+       :language: yaml
+    """
+
+    element_name = "org.biouno.unochoice.CascadeChoiceParameter"
+    pdef = XML.SubElement(xml_parent, element_name)
+
+    __active_choice_param_internal(pdef, data)
+
+    mapping = [
+        ("referenced-parameters", "referencedParameters", ""),
+        ("random-name", "randomName", "choice-param-{0}".format(data["name"]).lower()),
+        ("visible-items", "visibleItemCount", 1),
+    ]
+    helpers.convert_mapping_to_xml(pdef, data, mapping, fail_required=False)
+    XML.SubElement(pdef, "parameters", {"class": "linked-hash-map"})
+
+
+def __active_choice_param_internal(xml_parent, data):
     valid_choice_types_dict = {
         "single-select": "PT_SINGLE_SELECT",
         "multi-select": "PT_MULTI_SELECT",
@@ -1266,20 +1337,20 @@ def active_choices_param(registry, xml_parent, data):
         ("_project-full-name", "projectFullName", None),
     ]
 
-    main_script_xml = XML.SubElement(pdef, "script")
+    main_script_xml = XML.SubElement(xml_parent, "script")
     main_script_xml.set("class", "org.biouno.unochoice.model.GroovyScript")
-    __handle_unochoice_script(data, pdef, "fallback-script", main_script_xml)
-    __handle_unochoice_script(data, pdef, "script", main_script_xml)
+    __handle_unochoice_script(data, xml_parent, "fallback-script", main_script_xml)
+    __handle_unochoice_script(data, xml_parent, "script", main_script_xml)
 
-    helpers.convert_mapping_to_xml(pdef, data, mapping, fail_required=True)
+    helpers.convert_mapping_to_xml(xml_parent, data, mapping, fail_required=True)
 
 
 def dynamic_reference_param(registry, xml_parent, data):
     """yaml: dynamic-reference
     Active Choices Reactive Reference Parameter
 
-    Requires the Jenkins :jenkins-wiki:`Active Choices Plug-in
-    <active+choices+plugin>`.
+    Requires the Jenkins :jenkins-plugins:`Active Choices Plug-in
+    <uno-choice>`.
 
     :arg str name: Name of the parameter (required).
     :arg str description: Description of the parameter.
@@ -1389,8 +1460,35 @@ class Parameters(jenkins_jobs.modules.base.Base):
                 pdefs = XML.SubElement(pdefp, "parameterDefinitions")
             for param in parameters:
                 # Pass job name to the uno-choice plugin
-                param_type = next(iter(param))
-                if param_type in ("active-choices", "dynamic-reference"):
-                    param[param_type]["_project-name"] = data["name"].split("/")[-1]
-                    param[param_type]["_project-full-name"] = data["name"]
+                if isinstance(param, dict):
+                    param_type = next(iter(param))
+                    if param_type in (
+                        "active-choices",
+                        "active-choices-reactive",
+                        "dynamic-reference",
+                    ):
+                        param[param_type]["_project-name"] = data["name"].split("/")[-1]
+                        param[param_type]["_project-full-name"] = data["name"]
+                else:
+                    # Process macro case.
+                    # TODO: Find a way to do it more properly.
+                    # It's possible has an issue with macro parameter chain,
+                    # when a macro calls another macro with uno-choice plugin parameters.
+                    component = self.registry.parser_data.get("parameter", {}).get(
+                        param
+                    )
+                    for macro_param in component.get("parameters", []):
+                        for macro_param_type in macro_param:
+                            if macro_param_type in (
+                                "active-choices",
+                                "active-choices-reactive",
+                                "dynamic-reference",
+                            ):
+                                macro_param[macro_param_type]["_project-name"] = data[
+                                    "name"
+                                ].split("/")[-1]
+                                macro_param[macro_param_type][
+                                    "_project-full-name"
+                                ] = data["name"]
+
                 self.registry.dispatch("parameter", pdefs, param)
