@@ -36,5 +36,5 @@ class Freestyle(jenkins_jobs.modules.base.Base):
     sequence = 0
 
     def root_xml(self, data):
-        xml_parent = XML.Element('project')
+        xml_parent = XML.Element("project")
         return xml_parent
