@@ -431,6 +431,8 @@ def bitbucket_scm(xml_parent, data):
             * **before** (`bool`) - Clean the workspace before checkout
         * **prune** (`bool`) - Prune remote branches (default false)
         * **shallow-clone** (`bool`) - Perform shallow clone (default false)
+        * **sparse-checkout** (dict)
+            * **paths** (list) - List of paths to sparse checkout. (optional)
         * **depth** (`int`) - Set shallow clone depth (default 1)
         * **do-not-fetch-tags** (`bool`) - Perform a clone without tags
             (default false)
@@ -454,6 +456,8 @@ def bitbucket_scm(xml_parent, data):
             build changeset (default false)
         * **wipe-workspace** (`bool`) - Wipe out workspace before build
             (default true)
+        * **lfs-pull** (`bool`) - Call git lfs pull after checkout
+            (default false)
 
 
     Minimal Example:
@@ -617,22 +621,7 @@ def bitbucket_scm(xml_parent, data):
             cossh, data.get("checkout-over-ssh"), cossh_credentials, fail_required=True
         )
 
-    if data.get("filter-by-name-wildcard", None):
-        wscmf_name = XML.SubElement(
-            traits,
-            "jenkins.scm.impl.trait.WildcardSCMHeadFilterTrait",
-            {"plugin": "scm-api"},
-        )
-        wscmf_name_mapping = [
-            ("includes", "includes", ""),
-            ("excludes", "excludes", ""),
-        ]
-        helpers.convert_mapping_to_xml(
-            wscmf_name,
-            data.get("filter-by-name-wildcard", ""),
-            wscmf_name_mapping,
-            fail_required=True,
-        )
+    add_filter_by_name_wildcard_behaviors(traits, data)
 
     # handle the default git extensions like:
     # - clean
@@ -643,11 +632,12 @@ def bitbucket_scm(xml_parent, data):
     # - prune
     # - wipe-workspace
     # - use-author
+    # - lfs-pull
     git_extensions(traits, data)
 
 
 def gerrit_scm(xml_parent, data):
-    """Configure Gerrit SCM
+    r"""Configure Gerrit SCM
 
     Requires the :jenkins-plugins:`Gerrit Code Review Plugin
     <gerrit-code-review>`.
@@ -680,6 +670,41 @@ def gerrit_scm(xml_parent, data):
         'SCHEME' or 'ID'.
         query-string: Value of the query operator.
 
+    :extensions:
+
+        * **clean** (`dict`)
+            * **after** (`bool`) - Clean the workspace after checkout
+            * **before** (`bool`) - Clean the workspace before checkout
+        * **prune** (`bool`) - Prune remote branches (default false)
+        * **shallow-clone** (`bool`) - Perform shallow clone (default false)
+        * **sparse-checkout** (dict)
+            * **paths** (list) - List of paths to sparse checkout. (optional)
+        * **depth** (`int`) - Set shallow clone depth (default 1)
+        * **do-not-fetch-tags** (`bool`) - Perform a clone without tags
+            (default false)
+        * **submodule** (`dict`)
+            * **disable** (`bool`) - By disabling support for submodules you
+              can still keep using basic git plugin functionality and just have
+              Jenkins to ignore submodules completely as if they didn't exist.
+            * **recursive** (`bool`) - Retrieve all submodules recursively
+              (uses '--recursive' option which requires git>=1.6.5)
+            * **tracking** (`bool`) - Retrieve the tip of the configured
+              branch in .gitmodules (Uses '\-\-remote' option which requires
+              git>=1.8.2)
+            * **parent-credentials** (`bool`) - Use credentials from default
+              remote of parent repository (default false).
+            * **reference-repo** (`str`) - Path of the reference repo to use
+              during clone (optional)
+            * **timeout** (`int`) - Specify a timeout (in minutes) for
+              submodules operations (default 10).
+        * **timeout** (`str`) - Timeout for git commands in minutes (optional)
+        * **use-author** (`bool`): Use author rather than committer in Jenkin's
+            build changeset (default false)
+        * **wipe-workspace** (`bool`) - Wipe out workspace before build
+            (default true)
+        * **lfs-pull** (`bool`) - Call git lfs pull after checkout
+            (default false)
+
     Minimal Example:
 
     .. literalinclude::
@@ -759,6 +784,18 @@ def gerrit_scm(xml_parent, data):
             checks_trait, checks, checks_source_mapping, fail_required=True
         )
 
+    # handle the default git extensions like:
+    # - clean
+    # - shallow-clone
+    # - timeout
+    # - do-not-fetch-tags
+    # - submodule
+    # - prune
+    # - wipe-workspace
+    # - use-author
+    # - lfs-pull
+    git_extensions(traits, data)
+
 
 def git_scm(xml_parent, data):
     r"""Configure Git SCM
@@ -799,6 +836,8 @@ def git_scm(xml_parent, data):
             * **before** (`bool`) - Clean the workspace before checkout
         * **prune** (`bool`) - Prune remote branches (default false)
         * **shallow-clone** (`bool`) - Perform shallow clone (default false)
+        * **sparse-checkout** (dict)
+            * **paths** (list) - List of paths to sparse checkout. (optional)
         * **depth** (`int`) - Set shallow clone depth (default 1)
         * **do-not-fetch-tags** (`bool`) - Perform a clone without tags
             (default false)
@@ -822,6 +861,8 @@ def git_scm(xml_parent, data):
             build changeset (default false)
         * **wipe-workspace** (`bool`) - Wipe out workspace before build
             (default true)
+        * **lfs-pull** (`bool`) - Call git lfs pull after checkout
+            (default false)
 
     Minimal Example:
 
@@ -881,6 +922,7 @@ def git_scm(xml_parent, data):
     # - prune
     # - wipe-workspace
     # - use-author
+    # - lfs-pull
     git_extensions(traits, data)
 
 
@@ -933,6 +975,15 @@ def github_scm(xml_parent, data):
         (like to disable SCM triggering or to override the pipeline durability)
         (optional)
         Refer to :func:`~property_strategies <property_strategies>`.
+    :arg dict filter-by-name-wildcard: Enable filter by name with wildcards.
+        Requires the :jenkins-plugins:`SCM API Plugin <scm-api>`.
+
+        * **includes** ('str'): Space-separated list
+            of name patterns to consider. You may use * as a wildcard;
+            for example: `master release*`
+        * **excludes** ('str'): Name patterns to
+            ignore even if matched by the includes list.
+            For example: `release*`
 
     :extensions:
 
@@ -941,6 +992,8 @@ def github_scm(xml_parent, data):
             * **before** (`bool`) - Clean the workspace before checkout
         * **prune** (`bool`) - Prune remote branches (default false)
         * **shallow-clone** (`bool`) - Perform shallow clone (default false)
+        * **sparse-checkout** (dict)
+            * **paths** (list) - List of paths to sparse checkout. (optional)
         * **depth** (`int`) - Set shallow clone depth (default 1)
         * **do-not-fetch-tags** (`bool`) - Perform a clone without tags
             (default false)
@@ -969,6 +1022,8 @@ def github_scm(xml_parent, data):
             build changeset (default false)
         * **wipe-workspace** (`bool`) - Wipe out workspace before build
             (default true)
+        * **lfs-pull** (`bool`) - Call git lfs pull after checkout
+            (default false)
 
     Minimal Example:
 
@@ -1096,6 +1151,8 @@ def github_scm(xml_parent, data):
         XML.SubElement(rshf, "contextLabel").text = data.get("notification-context")
         XML.SubElement(rshf, "typeSuffix").text = "true"
 
+    add_filter_by_name_wildcard_behaviors(traits, data)
+
     # handle the default git extensions like:
     # - clean
     # - shallow-clone
@@ -1105,6 +1162,7 @@ def github_scm(xml_parent, data):
     # - prune
     # - wipe-workspace
     # - use-author
+    # - lfs-pull
     git_extensions(traits, data)
 
     if data.get("refspecs"):
@@ -1751,3 +1809,34 @@ def add_filter_branch_pr_behaviors(traits, data):
             wildcard_mapping,
             fail_required=True,
         )
+
+
+def add_filter_by_name_wildcard_behaviors(traits, data):
+    """Configure branch filtering behaviors.
+
+    :arg dict filter-by-name-wildcard: Enable filter by name with wildcards.
+        Requires the :jenkins-plugins:`SCM API Plugin <scm-api>`.
+
+        * **includes** ('str'): Space-separated list
+            of name patterns to consider. You may use * as a wildcard;
+            for example: `master release*`
+        * **excludes** ('str'): Name patterns to
+            ignore even if matched by the includes list.
+            For example: `release*`
+    """
+    if data.get("filter-by-name-wildcard", None):
+        wscmf_name = XML.SubElement(
+            traits,
+            "jenkins.scm.impl.trait.WildcardSCMHeadFilterTrait",
+            {"plugin": "scm-api"},
+        )
+        wscmf_name_mapping = [
+            ("includes", "includes", ""),
+            ("excludes", "excludes", ""),
+        ]
+        helpers.convert_mapping_to_xml(
+            wscmf_name,
+            data.get("filter-by-name-wildcard", ""),
+            wscmf_name_mapping,
+            fail_required=True,
+        )
