@@ -48,8 +48,8 @@ def builds_chain_fingerprinter(registry, xml_parent, data):
     """yaml: builds-chain-fingerprinter
     Builds chain fingerprinter.
 
-    Requires the Jenkins :jenkins-wiki:`Builds chain fingerprinter Plugin
-    <Builds+chain+fingerprinter>`.
+    Requires the Jenkins :jenkins-github:`Builds chain fingerprinter Plugin
+    <builds-chain-fingerprinter-plugin>`.
 
     :arg bool per-builds-chain: enable builds hierarchy fingerprinting
         (default false)
@@ -383,7 +383,7 @@ def branch_api(registry, xml_parent, data):
     :arg str time-period: The time period within which the maximum number
         of builds will be enforced. (default 'Hour')
 
-        :valid values: **Hour**, **Day**, **Week**, **Month**, **Year**
+        :valid values: **Second** **Minute** **Hour**, **Day**, **Week**, **Month**, **Year**
     :arg bool skip-rate-limit: Permit user triggered builds to
         skip the rate limit (default false)
 
@@ -404,7 +404,7 @@ def branch_api(registry, xml_parent, data):
     )
     branch.set("plugin", "branch-api")
 
-    valid_time_periods = ["Hour", "Day", "Week", "Month", "Year"]
+    valid_time_periods = ["Second", "Minute", "Hour", "Day", "Week", "Month", "Year"]
 
     mapping = [
         ("time-period", "durationName", "Hour", valid_time_periods),
@@ -527,7 +527,7 @@ def authenticated_build(registry, xml_parent, data):
     ).text = "hudson.model.Item.Build:authenticated"
 
 
-def authorization(registry, xml_parent, data):
+def authorization(registry, xml_parent, data, job_data):
     """yaml: authorization
     Specifies an authorization matrix
 
@@ -564,8 +564,7 @@ def authorization(registry, xml_parent, data):
        :language: yaml
     """
 
-    # check if it's a folder or a job
-    is_a_folder = data.pop("_is_a_folder", None) if data else False
+    is_a_folder = job_data.get("project-type") in ("folder", "multibranch")
 
     credentials = "com.cloudbees.plugins.credentials.CredentialsProvider."
     ownership = "com.synopsys.arc.jenkins.plugins.ownership.OwnershipPlugin."
@@ -1259,6 +1258,41 @@ def disable_resume(registry, xml_parent, data):
     )
 
 
+def resource_gating(registry, xml_parent, data):
+    """yaml: resource-gating
+    Jenkins Gating enables requiring external resources to be available before
+    build starts.
+
+    Requires the Jenkins: :jenkins-plugins:`Jenkins Gating <gating-core>`.
+
+    :arg list resources: Resource identifiers to be up before building
+
+    Example:
+
+    .. literalinclude:: /../../tests/properties/fixtures/gating-core.yaml
+        :language: yaml
+    """
+    if "resources" not in data.keys():
+        raise MissingAttributeError("resources")
+
+    gating = XML.SubElement(
+        xml_parent, "io.jenkins.plugins.gating.ResourceRequirementProperty"
+    )
+    gating.set("plugin", "gating-core")
+
+    resources = XML.SubElement(gating, "resources")
+    resources.set("class", "java.util.Collections$UnmodifiableRandomAccessList")
+    resources.set("resolves-to", "java.util.Collections$UnmodifiableList")
+
+    c = XML.SubElement(resources, "c")
+    c.set("class", "list")
+    for resource in data["resources"]:
+        XML.SubElement(c, "string").text = str(resource)
+
+    lst = XML.SubElement(resources, "list")
+    lst.set("reference", "../c")
+
+
 def cachet_gating(registry, xml_parent, data):
     """yaml: cachet-gating
     The Cachet Gating Plugin provides a gating mechanism
@@ -1434,15 +1468,4 @@ class Properties(jenkins_jobs.modules.base.Base):
             properties = XML.SubElement(xml_parent, "properties")
 
         for prop in data.get("properties", []):
-            # Pass a flag for folder permissions to the authorization method
-            if next(iter(prop)) == "authorization":
-                # Only projects are placed in folders
-                if "project-type" in data:
-                    if data["project-type"] in ("folder", "multibranch"):
-                        prop["authorization"]["_is_a_folder"] = True
-                    else:
-                        prop["authorization"]["_is_a_folder"] = False
-                else:
-                    prop["authorization"]["_is_a_folder"] = False
-
-            self.registry.dispatch("property", properties, prop)
+            self.registry.dispatch("property", properties, prop, job_data=data)
