@@ -322,11 +322,15 @@ def git(registry, xml_parent, data):
               during clone (optional)
             * **timeout** (`int`) - Specify a timeout (in minutes) for
               submodules operations (default 10).
+            * **threads** (`int`) - Number of parallel processes to be used when
+              updating submodules. Default is to use a single thread for submodule updates.
         * **timeout** (`str`) - Timeout for git commands in minutes (optional)
         * **use-author** (`bool`): Use author rather than committer in Jenkin's
             build changeset (default false)
         * **wipe-workspace** (`bool`) - Wipe out workspace before build
             (default true)
+        * **lfs-pull** (`bool`) - Call git lfs pull after checkout
+            (default false)
 
 
     Example:
@@ -633,9 +637,14 @@ def git_extensions(xml_parent, data):
     if trait and skip_notifications:
         trait_name = "com.cloudbees.jenkins.plugins.bitbucket.notifications.SkipNotificationsTrait"
         XML.SubElement(xml_parent, trait_name)
-    if not trait and "sparse-checkout" in data:
+    if "sparse-checkout" in data:
         ext_name = impl_prefix + "SparseCheckoutPaths"
-        ext = XML.SubElement(xml_parent, ext_name)
+        if trait:
+            trait_name = "SparseCheckoutPathsTrait"
+            tr = XML.SubElement(xml_parent, trait_prefix + trait_name)
+            ext = XML.SubElement(tr, "extension", {"class": ext_name})
+        else:
+            ext = XML.SubElement(xml_parent, ext_name)
         sparse_co = XML.SubElement(ext, "sparseCheckoutPaths")
         sparse_paths = data["sparse-checkout"].get("paths")
         if sparse_paths is not None:
@@ -668,6 +677,7 @@ def git_extensions(xml_parent, data):
             data["submodule"].get("reference-repo", "")
         )
         XML.SubElement(ext, "timeout").text = str(data["submodule"].get("timeout", 10))
+        XML.SubElement(ext, "threads").text = str(data["submodule"].get("threads", 1))
     if "timeout" in data:
         ext_name = impl_prefix + "CheckoutOption"
         if trait:
@@ -728,6 +738,16 @@ def git_extensions(xml_parent, data):
         else:
             ext = XML.SubElement(xml_parent, ext_name)
 
+    lfs_pull = str(data.get("lfs-pull", False)).lower()
+    if lfs_pull == "true":
+        ext_name = impl_prefix + "GitLFSPull"
+        if trait:
+            trait_name = "GitLFSPullTrait"
+            tr = XML.SubElement(xml_parent, trait_prefix + trait_name)
+            XML.SubElement(tr, "extension", {"class": ext_name})
+        else:
+            XML.SubElement(xml_parent, ext_name)
+
 
 def cvs(registry, xml_parent, data):
     """yaml: cvs
@@ -1706,6 +1726,7 @@ class SCM(jenkins_jobs.modules.base.Base):
 
         # multibranch-pipeline scm implementation is incompatible with SCM
         if data.get("project-type") in [
+            "githuborg",
             "multibranch",
             "multibranch-defaults",
             "pipeline",
